==> ejc-proequipmentcorp-impl-3.0.0-20230223.025151-333-sources.jar: com/ejianc/business/proequipmentcorpout/outStore/bean/OutStoreDetailEntity.java <==
package com.ejianc.business.proequipmentcorpout.outStore.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.Date;

/**
 * out-出库单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_outstore_detail")
public class OutStoreDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键IDpurchaseAcceptance
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="calculate_unit_name")
    private String calculateUnitName; // 计量单位名称
    @TableField(value="calculate_unit_id")
    private Long calculateUnitId; // 计量单位主键
    @TableField(value="rent_unit_id")
    private Long rentUnitId; // 计租单位主键
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="calculate_num")
    private BigDecimal calculateNum; // 计量数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="use_num")
    private BigDecimal useNum; // 库存可用数量
    @TableField(value="theory_weight")
    private BigDecimal theoryWeight; // 理论重量
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 皮重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="standard_offset_rate")
    private BigDecimal standardOffsetRate; // 标准偏差率
    @TableField(value="actual_offset_rate")
    private BigDecimal actualOffsetRate; // 实际偏差率
    @TableField(value="require_detail_flag")
    private Integer requireDetailFlag; // 是否符合要求 0-否，1-是
    @TableField(value="rent_detail_date")
    private Date rentDetailDate; // 计租日期
    @TableField(value="rent_type")
    private Integer rentType; // 计租方式
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "rent_calculation_type")
    private String rentCalculationType; // 计租方式：计租方式 day--日租，month--月租,engineering--工程量,other--其它费用
    @TableField(value = "trans_scale")
    private BigDecimal transScale; // 转换系数

    @TableField(value = "equip_leave_factory_code")
    private String equipLeaveFactoryCode; //设备出厂编码
    @TableField("equipment_state")
    private Integer equipmentState;

    /**
     * 生产厂家
     */
    @TableField(value = "production_manufactor")
    private String productionManufactor;

    @TableField(value = "store_equip_id")
    private Long storeEquipId; //仓库设备Id
    @TableField(value = "store_equip_name")
    private String storeEquipName; //仓库设备名称
    @TableField(value = "store_equip_code")
    private String storeEquipCode; //仓库设备编码

    /**
     * 单据来源类型: 0-合同设备，1-订单设备
     */
    @TableField(value = "source_type")
    private Integer sourceType;


    /**
     * 已出库数量
     */
    @TableField(value = "has_out_store_num")
    private BigDecimal hasOutStoreNum;

    /**
     * 订单数量
     */
    @TableField(value = "order_num")
    private BigDecimal orderNum;
    /**
     * 设备单价（无税）
     */
    @TableField(value = "price")
    private BigDecimal price;
    /**
     * 设备单价（含税）
     */
    @TableField(value = "tax_price")
    private BigDecimal taxPrice;
    /**
     * 设备税率
     */
    @TableField(value = "tax_rate")
    private BigDecimal taxRate;

    public BigDecimal getHasOutStoreNum() {
        return hasOutStoreNum;
    }

    public void setHasOutStoreNum(BigDecimal hasOutStoreNum) {
        this.hasOutStoreNum = hasOutStoreNum;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getCalculateUnitName() {
        return calculateUnitName;
    }

    public void setCalculateUnitName(String calculateUnitName) {
        this.calculateUnitName = calculateUnitName;
    }
    public Long getCalculateUnitId() {
        return calculateUnitId;
    }

    public void setCalculateUnitId(Long calculateUnitId) {
        this.calculateUnitId = calculateUnitId;
    }
    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCalculateNum() {
        return calculateNum;
    }

    public void setCalculateNum(BigDecimal calculateNum) {
        this.calculateNum = calculateNum;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public BigDecimal getStandardOffsetRate() {
        return standardOffsetRate;
    }

    public void setStandardOffsetRate(BigDecimal standardOffsetRate) {
        this.standardOffsetRate = standardOffsetRate;
    }
    public BigDecimal getActualOffsetRate() {
        return actualOffsetRate;
    }

    public void setActualOffsetRate(BigDecimal actualOffsetRate) {
        this.actualOffsetRate = actualOffsetRate;
    }
    public Integer getRequireDetailFlag() {
        return requireDetailFlag;
    }

    public void setRequireDetailFlag(Integer requireDetailFlag) {
        this.requireDetailFlag = requireDetailFlag;
    }
    public Date getRentDetailDate() {
        return rentDetailDate;
    }

    public void setRentDetailDate(Date rentDetailDate) {
        this.rentDetailDate = rentDetailDate;
    }
    public Integer getRentType() {
        return rentType;
    }

    public void setRentType(Integer rentType) {
        this.rentType = rentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getEquipLeaveFactoryCode() {
        return equipLeaveFactoryCode;
    }

    public void setEquipLeaveFactoryCode(String equipLeaveFactoryCode) {
        this.equipLeaveFactoryCode = equipLeaveFactoryCode;
    }

    public Long getStoreEquipId() {
        return storeEquipId;
    }

    public void setStoreEquipId(Long storeEquipId) {
        this.storeEquipId = storeEquipId;
    }

    public Integer getEquipmentState() {
        return equipmentState;
    }

    public void setEquipmentState(Integer equipmentState) {
        this.equipmentState = equipmentState;
    }

    public String getStoreEquipName() {
        return storeEquipName;
    }

    public void setStoreEquipName(String storeEquipName) {
        this.storeEquipName = storeEquipName;
    }

    public String getStoreEquipCode() {
        return storeEquipCode;
    }

    public void setStoreEquipCode(String storeEquipCode) {
        this.storeEquipCode = storeEquipCode;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20230525.035006-412-sources.jar: com/ejianc/business/proequipmentcorpout/outStore/bean/OutStoreDetailEntity.java <==
package com.ejianc.business.proequipmentcorpout.outStore.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.Date;

/**
 * out-出库单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_outstore_detail")
public class OutStoreDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键IDpurchaseAcceptance
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="calculate_unit_name")
    private String calculateUnitName; // 计量单位名称
    @TableField(value="calculate_unit_id")
    private Long calculateUnitId; // 计量单位主键
    @TableField(value="rent_unit_id")
    private Long rentUnitId; // 计租单位主键
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="calculate_num")
    private BigDecimal calculateNum; // 计量数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="use_num")
    private BigDecimal useNum; // 库存可用数量
    @TableField(value="theory_weight")
    private BigDecimal theoryWeight; // 理论重量
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 皮重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="standard_offset_rate")
    private BigDecimal standardOffsetRate; // 标准偏差率
    @TableField(value="actual_offset_rate")
    private BigDecimal actualOffsetRate; // 实际偏差率
    @TableField(value="require_detail_flag")
    private Integer requireDetailFlag; // 是否符合要求 0-否，1-是
    @TableField(value="rent_detail_date")
    private Date rentDetailDate; // 计租日期
    @TableField(value="rent_type")
    private Integer rentType; // 计租方式
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "rent_calculation_type")
    private String rentCalculationType; // 计租方式：计租方式 day--日租，month--月租,engineering--工程量,other--其它费用
    @TableField(value = "trans_scale")
    private BigDecimal transScale; // 转换系数

    @TableField(value = "equip_leave_factory_code")
    private String equipLeaveFactoryCode; //设备出厂编码
    @TableField("equipment_state")
    private Integer equipmentState;
    @TableField(value="property_right_company")
    private String propertyRightCompany; // 产权单位
    @TableField(value="install_location")
    private String installLocation; // 安装位置

    /**
     * 生产厂家
     */
    @TableField(value = "production_manufactor")
    private String productionManufactor;

    @TableField(value = "store_equip_id")
    private Long storeEquipId; //仓库设备Id
    @TableField(value = "store_equip_name")
    private String storeEquipName; //仓库设备名称
    @TableField(value = "store_equip_code")
    private String storeEquipCode; //仓库设备编码

    /**
     * 单据来源类型: 0-合同设备，1-订单设备
     */
    @TableField(value = "source_type")
    private Integer sourceType;


    /**
     * 已出库数量
     */
    @TableField(value = "has_out_store_num")
    private BigDecimal hasOutStoreNum;

    /**
     * 订单数量
     */
    @TableField(value = "order_num")
    private BigDecimal orderNum;
    /**
     * 设备单价（无税）
     */
    @TableField(value = "price")
    private BigDecimal price;
    /**
     * 设备单价（含税）
     */
    @TableField(value = "tax_price")
    private BigDecimal taxPrice;
    /**
     * 设备税率
     */
    @TableField(value = "tax_rate")
    private BigDecimal taxRate;

    public BigDecimal getHasOutStoreNum() {
        return hasOutStoreNum;
    }

    public void setHasOutStoreNum(BigDecimal hasOutStoreNum) {
        this.hasOutStoreNum = hasOutStoreNum;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getCalculateUnitName() {
        return calculateUnitName;
    }

    public void setCalculateUnitName(String calculateUnitName) {
        this.calculateUnitName = calculateUnitName;
    }
    public Long getCalculateUnitId() {
        return calculateUnitId;
    }

    public void setCalculateUnitId(Long calculateUnitId) {
        this.calculateUnitId = calculateUnitId;
    }
    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCalculateNum() {
        return calculateNum;
    }

    public void setCalculateNum(BigDecimal calculateNum) {
        this.calculateNum = calculateNum;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public BigDecimal getStandardOffsetRate() {
        return standardOffsetRate;
    }

    public void setStandardOffsetRate(BigDecimal standardOffsetRate) {
        this.standardOffsetRate = standardOffsetRate;
    }
    public BigDecimal getActualOffsetRate() {
        return actualOffsetRate;
    }

    public void setActualOffsetRate(BigDecimal actualOffsetRate) {
        this.actualOffsetRate = actualOffsetRate;
    }
    public Integer getRequireDetailFlag() {
        return requireDetailFlag;
    }

    public void setRequireDetailFlag(Integer requireDetailFlag) {
        this.requireDetailFlag = requireDetailFlag;
    }
    public Date getRentDetailDate() {
        return rentDetailDate;
    }

    public void setRentDetailDate(Date rentDetailDate) {
        this.rentDetailDate = rentDetailDate;
    }
    public Integer getRentType() {
        return rentType;
    }

    public void setRentType(Integer rentType) {
        this.rentType = rentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getEquipLeaveFactoryCode() {
        return equipLeaveFactoryCode;
    }

    public void setEquipLeaveFactoryCode(String equipLeaveFactoryCode) {
        this.equipLeaveFactoryCode = equipLeaveFactoryCode;
    }

    public Long getStoreEquipId() {
        return storeEquipId;
    }

    public void setStoreEquipId(Long storeEquipId) {
        this.storeEquipId = storeEquipId;
    }

    public Integer getEquipmentState() {
        return equipmentState;
    }

    public void setEquipmentState(Integer equipmentState) {
        this.equipmentState = equipmentState;
    }

    public String getStoreEquipName() {
        return storeEquipName;
    }

    public void setStoreEquipName(String storeEquipName) {
        this.storeEquipName = storeEquipName;
    }

    public String getStoreEquipCode() {
        return storeEquipCode;
    }

    public void setStoreEquipCode(String storeEquipCode) {
        this.storeEquipCode = storeEquipCode;
    }

    public String getPropertyRightCompany() {
        return propertyRightCompany;
    }

    public void setPropertyRightCompany(String propertyRightCompany) {
        this.propertyRightCompany = propertyRightCompany;
    }

    public String getInstallLocation() {
        return installLocation;
    }

    public void setInstallLocation(String installLocation) {
        this.installLocation = installLocation;
    }
}
